@@ -4,23 +4,27 @@
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
-import os, sys
+import os
+import sys
+import logging
 from util import (
-                    LazyMixin,
-                    stream_copy
-                )
+    LazyMixin,
+    stream_copy
+)
 from exc import GitCommandError
 
 from subprocess import (
-                            call,
-                            Popen,
-                            PIPE
-                        )
+    call,
+    Popen,
+    PIPE
+)
 
 execute_kwargs = ('istream', 'with_keep_cwd', 'with_extended_output',
                   'with_exceptions', 'as_process',
                   'output_stream')
 
+log = logging.getLogger('git.cmd')
+
 __all__ = ('Git', )
 
 
@@ -29,6 +33,7 @@ def dashify(string):
 
 
 class Git(LazyMixin):
+
     """
     The Git class manages communication with the Git binary.
 
@@ -246,7 +251,7 @@ class Git(LazyMixin):
             self._version_info = tuple(int(n) for n in version_numbers.split('.')[:4] if n.isdigit())
         else:
             super(Git, self)._set_cache_(attr)
-        #END handle version info
+        # END handle version info
 
     @property
     def working_dir(self):
@@ -331,30 +336,30 @@ class Git(LazyMixin):
         :note:
            If you add additional keyword arguments to the signature of this method,
            you must update the execute_kwargs tuple housed in this module."""
-        if self.GIT_PYTHON_TRACE and not self.GIT_PYTHON_TRACE == 'full':
-            print ' '.join(command)
+        if self.GIT_PYTHON_TRACE and (self.GIT_PYTHON_TRACE != 'full' or as_process):
+            log.info(' '.join(command))
 
         # Allow the user to have the command executed in their working dir.
         if with_keep_cwd or self._working_dir is None:
-          cwd = os.getcwd()
+            cwd = os.getcwd()
         else:
-          cwd = self._working_dir
+            cwd = self._working_dir
 
         # Start the process
         env = os.environ.copy()
         env["LC_MESSAGES"] = "C"
         proc = Popen(command,
-                        env=env,
-                        cwd=cwd,
-                        stdin=istream,
-                        stderr=PIPE,
-                        stdout=PIPE,
-                        # Prevent cmd prompt popups on windows by using a shell ... .
-                        # See https://github.com/gitpython-developers/GitPython/pull/126
-                        shell=sys.platform == 'win32',
-                        close_fds=(os.name == 'posix'),  # unsupported on linux
-                        **subprocess_kwargs
-                        )
+                     env=env,
+                     cwd=cwd,
+                     stdin=istream,
+                     stderr=PIPE,
+                     stdout=PIPE,
+                     # Prevent cmd prompt popups on windows by using a shell ... .
+                     # See https://github.com/gitpython-developers/GitPython/pull/126
+                     shell=sys.platform == 'win32',
+                     close_fds=(os.name == 'posix'),  # unsupported on linux
+                     **subprocess_kwargs
+                     )
         if as_process:
             return self.AutoInterrupt(proc, command)
 
@@ -387,11 +392,11 @@ class Git(LazyMixin):
         if self.GIT_PYTHON_TRACE == 'full':
             cmdstr = " ".join(command)
             if stderr_value:
-                print "%s -> %d; stdout: '%s'; stderr: '%s'" % (cmdstr, status, stdout_value, stderr_value)
+                log.info("%s -> %d; stdout: '%s'; stderr: '%s'", cmdstr, status, stdout_value, stderr_value)
             elif stdout_value:
-                print "%s -> %d; stdout: '%s'" % (cmdstr, status, stdout_value)
+                log.info("%s -> %d; stdout: '%s'", cmdstr, status, stdout_value)
             else:
-                print "%s -> %d" % (cmdstr, status)
+                log.info("%s -> %d", cmdstr, status)
         # END handle debug printing
 
         if with_exceptions and status != 0:
@@ -508,7 +513,7 @@ class Git(LazyMixin):
             call.extend([dashify(method)])
             call.extend(args)
             return call
-        #END utility to recreate call after changes
+        # END utility to recreate call after changes
 
         if sys.platform == 'win32':
             try:
@@ -518,25 +523,27 @@ class Git(LazyMixin):
                     # did we switch to git.cmd already, or was it changed from default ? permanently fail
                     if self.GIT_PYTHON_GIT_EXECUTABLE != self.git_exec_name:
                         raise
-                    #END handle overridden variable
+                    # END handle overridden variable
                     type(self).GIT_PYTHON_GIT_EXECUTABLE = self.git_exec_name_win
-                    call = [self.GIT_PYTHON_GIT_EXECUTABLE] + list(args)
 
                     try:
                         return self.execute(make_call(), **_kwargs)
                     finally:
                         import warnings
-                        msg = "WARNING: Automatically switched to use git.cmd as git executable, which reduces performance by ~70%."
-                        msg += "Its recommended to put git.exe into the PATH or to set the %s environment variable to the executable's location" % self._git_exec_env_var
+                        msg = "WARNING: Automatically switched to use git.cmd as git executable"
+                        msg += ", which reduces performance by ~70%."
+                        msg += "Its recommended to put git.exe into the PATH or to "
+                        msg += "set the %s " % self._git_exec_env_var
+                        msg += "environment variable to the executable's location"
                         warnings.warn(msg)
-                    #END print of warning
-                #END catch first failure
+                    # END print of warning
+                # END catch first failure
             except WindowsError:
                 raise WindowsError("The system cannot find or execute the file at %r" % self.GIT_PYTHON_GIT_EXECUTABLE)
-            #END provide better error message
+            # END provide better error message
         else:
             return self.execute(make_call(), **_kwargs)
-        #END handle windows default installation
+        # END handle windows default installation
 
     def _parse_object_header(self, header_line):
         """
