@@ -7,10 +7,9 @@
 configuration files"""
 
 import re
-import os
 import ConfigParser as cp
 import inspect
-import cStringIO
+import logging
 
 from git.odict import OrderedDict
 from git.util import LockFile
@@ -18,6 +17,9 @@ from git.util import LockFile
 __all__ = ('GitConfigParser', 'SectionConstraint')
 
 
+log = logging.getLogger('git.config')
+
+
 class MetaParserBuilder(type):
 
     """Utlity class wrapping base-class methods into decorators that assure read-only properties"""
@@ -80,7 +82,7 @@ class SectionConstraint(object):
     It supports all ConfigParser methods that operate on an option"""
     __slots__ = ("_config", "_section_name")
     _valid_attrs_ = ("get_value", "set_value", "get", "set", "getint", "getfloat", "getboolean", "has_option",
-                    "remove_section", "remove_option", "options")
+                     "remove_section", "remove_option", "options")
 
     def __init__(self, config, section):
         self._config = config
@@ -136,7 +138,7 @@ class GitConfigParser(cp.RawConfigParser, object):
                                               # (either : or =), followed
                                               # by any # space/tab
         r'(?P<value>.*)$'                     # everything up to eol
-        )
+    )
 
     # list of RawConfigParser methods able to change the instance
     _mutating_methods_ = ("add_section", "remove_section", "remove_option", "set")
@@ -165,7 +167,8 @@ class GitConfigParser(cp.RawConfigParser, object):
 
         if not read_only:
             if isinstance(file_or_files, (tuple, list)):
-                raise ValueError("Write-ConfigParsers can operate on a single file only, multiple files have been passed")
+                raise ValueError(
+                    "Write-ConfigParsers can operate on a single file only, multiple files have been passed")
             # END single file check
 
             if not isinstance(file_or_files, basestring):
@@ -187,8 +190,8 @@ class GitConfigParser(cp.RawConfigParser, object):
         try:
             try:
                 self.write()
-            except IOError, e:
-                print "Exception during destruction of GitConfigParser: %s" % str(e)
+            except IOError:
+                log.error("Exception during destruction of GitConfigParser", exc_info=True)
         finally:
             self._lock._release_lock()
 
@@ -286,7 +289,7 @@ class GitConfigParser(cp.RawConfigParser, object):
                 try:
                     fp = open(file_object)
                     close_fp = True
-                except IOError, e:
+                except IOError:
                     continue
             # END fp handling
 
@@ -338,7 +341,7 @@ class GitConfigParser(cp.RawConfigParser, object):
             # make sure we do not overwrite into an existing file
             if hasattr(fp, 'truncate'):
                 fp.truncate()
-            #END
+            # END
         # END handle stream or file
 
         # WRITE DATA
