@@ -13,54 +13,51 @@ from cStringIO import StringIO
 from stat import S_ISLNK
 
 from typ import (
-                    BaseIndexEntry,
-                    IndexEntry,
-                )
+    BaseIndexEntry,
+    IndexEntry,
+)
 
 from util import (
-                    TemporaryFileSwap,
-                    post_clear_cache,
-                    default_index,
-                    git_working_dir
-                )
+    TemporaryFileSwap,
+    post_clear_cache,
+    default_index,
+    git_working_dir
+)
 
-import git.objects
 import git.diff as diff
 
 from git.exc import (
-                            GitCommandError,
-                            CheckoutError
-                        )
+    GitCommandError,
+    CheckoutError
+)
 
 from git.objects import (
-                            Blob,
-                            Submodule,
-                            Tree,
-                            Object,
-                            Commit,
-                        )
+    Blob,
+    Submodule,
+    Tree,
+    Object,
+    Commit,
+)
 
 from git.objects.util import Serializable
 
 from git.util import (
-                            IndexFileSHA1Writer,
-                            LazyMixin,
-                            LockedFD,
-                            join_path_native,
-                            file_contents_ro,
-                            to_native_path_linux,
-                            to_native_path
-                        )
+    LazyMixin,
+    LockedFD,
+    join_path_native,
+    file_contents_ro,
+    to_native_path_linux,
+)
 
 from fun import (
-                    entry_key,
-                    write_cache,
-                    read_cache,
-                    aggressive_tree_merge,
-                    write_tree_from_cache,
-                    stat_mode_to_index_mode,
-                    S_IFGITLINK
-                )
+    entry_key,
+    write_cache,
+    read_cache,
+    aggressive_tree_merge,
+    write_tree_from_cache,
+    stat_mode_to_index_mode,
+    S_IFGITLINK
+)
 
 from gitdb.base import IStream
 from gitdb.db import MemoryDB
@@ -380,7 +377,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         # END for each path
 
     def _write_path_to_stdin(self, proc, filepath, item, fmakeexc, fprogress,
-                                read_from_stdout=True):
+                             read_from_stdout=True):
         """Write path to proc.stdin and make sure it processes the item, including progress.
 
         :return: stdout string
@@ -418,9 +415,6 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             iterator. A default filter, the BlobFilter, allows you to yield blobs
             only if they match a given list of paths. """
         for entry in self.entries.itervalues():
-            # TODO: is it necessary to convert the mode ? We did that when adding
-            # it to the index, right ?
-            mode = stat_mode_to_index_mode(entry.mode)
             blob = entry.to_blob(self.repo)
             blob.size = entry.size
             output = (entry.stage, blob)
@@ -572,8 +566,8 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         fprogress(filepath, False, filepath)
         istream = self.repo.odb.store(IStream(Blob.type, st.st_size, stream))
         fprogress(filepath, True, filepath)
-        return BaseIndexEntry((stat_mode_to_index_mode(st.st_mode), 
-                            istream.binsha, 0, to_native_path_linux(filepath)))
+        return BaseIndexEntry((stat_mode_to_index_mode(st.st_mode),
+                               istream.binsha, 0, to_native_path_linux(filepath)))
 
     @git_working_dir
     def _entries_for_paths(self, paths, path_rewriter, fprogress, entries):
@@ -581,9 +575,9 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         if path_rewriter:
             for path in paths:
                 abspath = os.path.abspath(path)
-                gitrelative_path = abspath[len(self.repo.working_tree_dir)+1:]
-                blob = Blob(self.repo, Blob.NULL_BIN_SHA, 
-                            stat_mode_to_index_mode(os.stat(abspath).st_mode), 
+                gitrelative_path = abspath[len(self.repo.working_tree_dir) + 1:]
+                blob = Blob(self.repo, Blob.NULL_BIN_SHA,
+                            stat_mode_to_index_mode(os.stat(abspath).st_mode),
                             to_native_path_linux(gitrelative_path))
                 # TODO: variable undefined
                 entries.append(BaseIndexEntry.from_blob(blob))
@@ -599,11 +593,10 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         # END path handling
         return entries_added
 
-
-    def add(self, items, force=True, fprogress=lambda *args: None, path_rewriter=None, 
-                write=True):
+    def add(self, items, force=True, fprogress=lambda *args: None, path_rewriter=None,
+            write=True):
         """Add files from the working tree, specific blobs or BaseIndexEntries
-        to the index. 
+        to the index.
 
         :param items:
             Multiple types of items are supported, types can be mixed within one call.
@@ -631,7 +624,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
                 must be a path relative to our repository.
 
                 If their sha is null ( 40*0 ), their path must exist in the file system
-                relative to the git repository as an object will be created from 
+                relative to the git repository as an object will be created from
                 the data at the path.
                 The handling now very much equals the way string paths are processed, except that
                 the mode you have set will be kept. This allows you to create symlinks
@@ -676,7 +669,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         :param write:
                 If True, the index will be written once it was altered. Otherwise
                 the changes only exist in memory and are not available to git commands.
-        
+
         :return:
             List(BaseIndexEntries) representing the entries just actually added.
 
@@ -698,23 +691,25 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
         # HANDLE ENTRIES
         if entries:
-            null_mode_entries = [ e for e in entries if e.mode == 0 ]
+            null_mode_entries = [e for e in entries if e.mode == 0]
             if null_mode_entries:
-                raise ValueError("At least one Entry has a null-mode - please use index.remove to remove files for clarity")
+                raise ValueError(
+                    "At least one Entry has a null-mode - please use index.remove to remove files for clarity")
             # END null mode should be remove
 
             # HANLDE ENTRY OBJECT CREATION
             # create objects if required, otherwise go with the existing shas
-            null_entries_indices = [ i for i,e in enumerate(entries) if e.binsha == Object.NULL_BIN_SHA ]
+            null_entries_indices = [i for i, e in enumerate(entries) if e.binsha == Object.NULL_BIN_SHA]
             if null_entries_indices:
                 @git_working_dir
                 def handle_null_entries(self):
                     for ei in null_entries_indices:
                         null_entry = entries[ei]
                         new_entry = self._store_path(null_entry.path, fprogress)
-                        
+
                         # update null entry
-                        entries[ei] = BaseIndexEntry((null_entry.mode, new_entry.binsha, null_entry.stage, null_entry.path))
+                        entries[ei] = BaseIndexEntry(
+                            (null_entry.mode, new_entry.binsha, null_entry.stage, null_entry.path))
                     # END for each entry index
                 # end closure
                 handle_null_entries(self)
@@ -724,7 +719,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
             # If we have to rewrite the entries, do so now, after we have generated
             # all object sha's
             if path_rewriter:
-                for i,e in enumerate(entries):
+                for i, e in enumerate(entries):
                     entries[i] = BaseIndexEntry((e.mode, e.binsha, e.stage, path_rewriter(e)))
                 # END for each entry
             # END handle path rewriting
@@ -744,11 +739,11 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         # add the new entries to this instance
         for entry in entries_added:
             self.entries[(entry.path, 0)] = IndexEntry.from_base(entry)
-            
+
         if write:
             self.write()
         # END handle write
-        
+
         return entries_added
 
     def _items_to_rela_paths(self, items):
@@ -891,7 +886,8 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         :return:
             Commit object representing the new commit"""
         tree = self.write_tree()
-        return Commit.create_from_tree(self.repo, tree, message, parent_commits, head, author=author, committer=committer)
+        return Commit.create_from_tree(self.repo, tree, message, parent_commits,
+                                       head, author=author, committer=committer)
 
     @classmethod
     def _flush_stdin_and_wait(cls, proc, ignore_stdout=False):
@@ -993,7 +989,9 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
                 raise GitCommandError(("git-checkout-index", ), 128, stderr)
             if failed_files:
                 valid_files = list(set(iter_checked_out_files) - set(failed_files))
-                raise CheckoutError("Some files could not be checked out from the index due to local modifications", failed_files, valid_files, failed_reasons)
+                raise CheckoutError(
+                    "Some files could not be checked out from the index due to local modifications",
+                    failed_files, valid_files, failed_reasons)
         # END stderr handler
 
         if paths is None:
@@ -1037,7 +1035,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
                         if entry.path.startswith(dir):
                             p = entry.path
                             self._write_path_to_stdin(proc, p, p, make_exc,
-                                                        fprogress, read_from_stdout=False)
+                                                      fprogress, read_from_stdout=False)
                             checked_out_files.append(p)
                             path_is_directory = True
                         # END if entry is in directory
@@ -1046,7 +1044,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
                 if not path_is_directory:
                     self._write_path_to_stdin(proc, co_path, path, make_exc,
-                                                fprogress, read_from_stdout=False)
+                                              fprogress, read_from_stdout=False)
                     checked_out_files.append(co_path)
                 # END path is a file
             # END for each path
