@@ -5,11 +5,11 @@
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
 from git.util import (
-                            Actor,
-                            Iterable,
-                            Stats,
-                            finalize_process
-                        )
+    Actor,
+    Iterable,
+    Stats,
+    finalize_process
+)
 from git.diff import Diffable
 from tree import Tree
 from gitdb import IStream
@@ -17,21 +17,23 @@ from cStringIO import StringIO
 
 import base
 from gitdb.util import (
-                        hex_to_bin
-                        )
+    hex_to_bin
+)
 from util import (
-                        Traversable,
-                        Serializable,
-                        parse_date,
-                        altz_to_utctz_str,
-                        parse_actor_and_date
-                    )
+    Traversable,
+    Serializable,
+    parse_date,
+    altz_to_utctz_str,
+    parse_actor_and_date
+)
 from time import (
-                    time,
-                    altzone
-                )
+    time,
+    altzone
+)
 import os
-import sys
+import logging
+
+log = logging.getLogger('git.objects.commit')
 
 __all__ = ('Commit', )
 
@@ -276,9 +278,9 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
             If True, the HEAD will be advanced to the new commit automatically.
             Else the HEAD will remain pointing on the previous commit. This could
             lead to undesired results when diffing files.
-        :param author: The name of the author, optional. If unset, the repository 
+        :param author: The name of the author, optional. If unset, the repository
             configuration is used to obtain this value.
-        :param committer: The name of the committer, optional. If unset, the 
+        :param committer: The name of the committer, optional. If unset, the
             repository configuration is used to obtain this value.
 
         :return: Commit object representing the new commit
@@ -339,9 +341,9 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
 
         # CREATE NEW COMMIT
         new_commit = cls(repo, cls.NULL_BIN_SHA, tree,
-                        author, author_time, author_offset,
-                        committer, committer_time, committer_offset,
-                        message, parent_commits, conf_encoding)
+                         author, author_time, author_offset,
+                         committer, committer_time, committer_offset,
+                         message, parent_commits, conf_encoding)
 
         stream = StringIO()
         new_commit._serialize(stream)
@@ -384,8 +386,8 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         c = self.committer
         fmt = "%s %s <%s> %s %s\n"
         write(fmt % ("author", aname, a.email,
-                        self.authored_date,
-                        altz_to_utctz_str(self.author_tz_offset)))
+                     self.authored_date,
+                     altz_to_utctz_str(self.author_tz_offset)))
 
         # encode committer
         aname = c.name
@@ -393,8 +395,8 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
             aname = aname.encode(self.encoding)
         # END handle unicode in name
         write(fmt % ("committer", aname, c.email,
-                        self.committed_date,
-                        altz_to_utctz_str(self.committer_tz_offset)))
+                     self.committed_date,
+                     altz_to_utctz_str(self.committer_tz_offset)))
 
         if self.encoding != self.default_encoding:
             write("encoding %s\n" % self.encoding)
@@ -457,7 +459,8 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
                 is_next_header = False
                 while True:
                     sigbuf = readline()
-                    if sigbuf == "": break
+                    if sigbuf == "":
+                        break
                     if sigbuf[0:1] != " ":
                         buf = sigbuf.strip()
                         is_next_header = True
@@ -472,14 +475,16 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         try:
             self.author.name = self.author.name.decode(self.encoding)
         except UnicodeDecodeError:
-            print >> sys.stderr, "Failed to decode author name '%s' using encoding %s" % (self.author.name, self.encoding)
+            log.error("Failed to decode author name '%s' using encoding %s", self.author.name, self.encoding,
+                      exc_info=True)
         # END handle author's encoding
 
         # decode committer name
         try:
             self.committer.name = self.committer.name.decode(self.encoding)
         except UnicodeDecodeError:
-            print >> sys.stderr, "Failed to decode committer name '%s' using encoding %s" % (self.committer.name, self.encoding)
+            log.error("Failed to decode committer name '%s' using encoding %s", self.committer.name, self.encoding,
+                      exc_info=True)
         # END handle author's encoding
 
         # a stream from our data simply gives us the plain message
@@ -488,7 +493,7 @@ class Commit(base.Object, Iterable, Diffable, Traversable, Serializable):
         try:
             self.message = self.message.decode(self.encoding)
         except UnicodeDecodeError:
-            print >> sys.stderr, "Failed to decode message '%s' using encoding %s" % (self.message, self.encoding)
+            log.error("Failed to decode message '%s' using encoding %s", self.message, self.encoding, exc_info=True)
         # END exception handling
         return self
 
