@@ -11,13 +11,13 @@ from submodule.base import Submodule
 import git.diff as diff
 
 from fun import (
-                    tree_entries_from_data,
-                    tree_to_stream
-                 )
+    tree_entries_from_data,
+    tree_to_stream
+)
 
 from gitdb.util import (
-                        to_bin_sha,
-                        )
+    to_bin_sha,
+)
 
 __all__ = ("TreeModifier", "Tree")
 
@@ -119,17 +119,17 @@ class Tree(IndexObject, diff.Diffable, util.Traversable, util.Serializable):
     __slots__ = "_cache"
 
     # actual integer ids for comparison
-    commit_id = 016     # equals stat.S_IFDIR | stat.S_IFLNK - a directory link
-    blob_id = 010
-    symlink_id = 012
-    tree_id = 004
+    commit_id = 0o16     # equals stat.S_IFDIR | stat.S_IFLNK - a directory link
+    blob_id = 0o10
+    symlink_id = 0o12
+    tree_id = 0o04
 
     _map_id_to_type = {
-                        commit_id: Submodule,
-                        blob_id: Blob,
-                        symlink_id: Blob
-                        # tree id added once Tree is defined
-                        }
+        commit_id: Submodule,
+        blob_id: Blob,
+        symlink_id: Blob
+        # tree id added once Tree is defined
+    }
 
     def __init__(self, repo, binsha, mode=tree_id << 12, path=None):
         super(Tree, self).__init__(repo, binsha, mode, path)
@@ -187,7 +187,8 @@ class Tree(IndexObject, diff.Diffable, util.Traversable, util.Serializable):
         else:
             for info in self._cache:
                 if info[2] == file:     # [2] == name
-                    return self._map_id_to_type[info[1] >> 12](self.repo, info[0], info[1], join_path(self.path, info[2]))
+                    return self._map_id_to_type[info[1] >> 12](self.repo, info[0], info[1],
+                                                               join_path(self.path, info[2]))
             # END for each obj
             raise KeyError(msg % file)
         # END handle long paths
@@ -212,8 +213,8 @@ class Tree(IndexObject, diff.Diffable, util.Traversable, util.Serializable):
         return TreeModifier(self._cache)
 
     def traverse(self, predicate=lambda i, d: True,
-                           prune=lambda i, d: False, depth=-1, branch_first=True,
-                           visit_once=False, ignore_self=1):
+                 prune=lambda i, d: False, depth=-1, branch_first=True,
+                 visit_once=False, ignore_self=1):
         """For documentation, see util.Traversable.traverse
         Trees are set to visit_once = False to gain more performance in the traversal"""
         return super(Tree, self).traverse(predicate, prune, depth, branch_first, visit_once, ignore_self)
