@@ -5,20 +5,20 @@
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 """Module for general utility functions"""
 from git.util import (
-                        IterableList,
-                        Actor
-                    )
+    IterableList,
+    Actor
+)
 
 import re
 from collections import deque as Deque
 
 from string import digits
 import time
-import os
+import calendar
 
 __all__ = ('get_object_type_by_name', 'parse_date', 'parse_actor_and_date',
-            'ProcessStreamAdapter', 'Traversable', 'altz_to_utctz_str', 'utctz_to_altz',
-            'verify_utctz', 'Actor')
+           'ProcessStreamAdapter', 'Traversable', 'altz_to_utctz_str', 'utctz_to_altz',
+           'verify_utctz', 'Actor')
 
 #{ Functions
 
@@ -88,10 +88,10 @@ def verify_utctz(offset):
         raise fmt_exc
     if offset[0] not in "+-":
         raise fmt_exc
-    if  offset[1] not in digits or \
-        offset[2] not in digits or \
-        offset[3] not in digits or \
-        offset[4] not in digits:
+    if offset[1] not in digits or\
+       offset[2] not in digits or\
+       offset[3] not in digits or\
+       offset[4] not in digits:
         raise fmt_exc
     # END for each char
     return offset
@@ -106,9 +106,10 @@ def parse_date(string_date):
         * ISO 8601 2005-04-07T22:13:13
             The T can be a space as well
 
-    :return: Tuple(int(timestamp), int(offset)), both in seconds since epoch
+    :return: Tuple(int(timestamp_UTC), int(offset)), both in seconds since epoch
     :raise ValueError: If the format could not be understood
-    :note: Date can also be YYYY.MM.DD, MM/DD/YYYY and DD.MM.YYYY"""
+    :note: Date can also be YYYY.MM.DD, MM/DD/YYYY and DD.MM.YYYY.
+    """
     # git time
     try:
         if string_date.count(' ') == 1 and string_date.rfind(':') == -1:
@@ -121,6 +122,7 @@ def parse_date(string_date):
                 offset = verify_utctz(string_date[-5:])
                 string_date = string_date[:-6]  # skip space as well
             # END split timezone info
+            offset = utctz_to_altz(offset)
 
             # now figure out the date and time portion - split time
             date_formats = list()
@@ -153,10 +155,10 @@ def parse_date(string_date):
             for fmt in date_formats:
                 try:
                     dtstruct = time.strptime(date_part, fmt)
-                    fstruct = time.struct_time((dtstruct.tm_year, dtstruct.tm_mon, dtstruct.tm_mday,
-                                                tstruct.tm_hour, tstruct.tm_min, tstruct.tm_sec,
-                                                dtstruct.tm_wday, dtstruct.tm_yday, tstruct.tm_isdst))
-                    return int(time.mktime(fstruct)), utctz_to_altz(offset)
+                    utctime = calendar.timegm((dtstruct.tm_year, dtstruct.tm_mon, dtstruct.tm_mday,
+                                               tstruct.tm_hour, tstruct.tm_min, tstruct.tm_sec,
+                                               dtstruct.tm_wday, dtstruct.tm_yday, tstruct.tm_isdst))
+                    return int(utctime), offset
                 except ValueError:
                     continue
                 # END exception handling
@@ -238,8 +240,8 @@ class Traversable(object):
         return out
 
     def traverse(self, predicate=lambda i, d: True,
-                           prune=lambda i, d: False, depth=-1, branch_first=True,
-                           visit_once=True, ignore_self=1, as_edge=False):
+                 prune=lambda i, d: False, depth=-1, branch_first=True,
+                 visit_once=True, ignore_self=1, as_edge=False):
         """:return: iterator yieling of items found when traversing self
 
         :param predicate: f(i,d) returns False if item i at depth d should not be included in the result
