@@ -11,28 +11,27 @@ from ConfigParser import NoOptionError
 from config import SectionConstraint
 
 from git.util import (
-                        LazyMixin,
-                        Iterable,
-                        IterableList,
-                        RemoteProgress
-                        )
+    LazyMixin,
+    Iterable,
+    IterableList,
+    RemoteProgress
+)
 
 from refs import (
-                    Reference,
-                    RemoteReference,
-                    SymbolicReference,
-                    TagReference
-                )
+    Reference,
+    RemoteReference,
+    SymbolicReference,
+    TagReference
+)
 
 from git.util import (
     join_path,
     finalize_process
-    )
+)
 from gitdb.util import join
 
 import re
 import os
-import sys
 
 __all__ = ('RemoteProgress', 'PushInfo', 'FetchInfo', 'Remote')
 
@@ -72,8 +71,8 @@ def add_progress(kwargs, git, progress):
         v = git.version_info
         if v[0] > 1 or v[1] > 7 or v[2] > 0 or v[3] > 3:
             kwargs['progress'] = True
-        #END handle --progress
-    #END handle progress
+        # END handle --progress
+    # END handle progress
     return kwargs
 
 #} END utilities
@@ -98,14 +97,18 @@ class PushInfo(object):
     __slots__ = ('local_ref', 'remote_ref_string', 'flags', 'old_commit', '_remote', 'summary')
 
     NEW_TAG, NEW_HEAD, NO_MATCH, REJECTED, REMOTE_REJECTED, REMOTE_FAILURE, DELETED, \
-    FORCED_UPDATE, FAST_FORWARD, UP_TO_DATE, ERROR = [1 << x for x in range(11)]
+        FORCED_UPDATE, FAST_FORWARD, UP_TO_DATE, ERROR = [1 << x for x in range(11)]
 
-    _flag_map = {'X': NO_MATCH, '-': DELETED, '*': 0,
-                    '+': FORCED_UPDATE, ' ': FAST_FORWARD,
-                    '=': UP_TO_DATE, '!': ERROR}
+    _flag_map = {'X': NO_MATCH,
+                 '-': DELETED,
+                 '*': 0,
+                 '+': FORCED_UPDATE,
+                 ' ': FAST_FORWARD,
+                 '=': UP_TO_DATE,
+                 '!': ERROR}
 
     def __init__(self, flags, local_ref, remote_ref_string, remote, old_commit=None,
-                    summary=''):
+                 summary=''):
         """ Initialize a new instance """
         self.flags = flags
         self.local_ref = local_ref
@@ -199,13 +202,17 @@ class FetchInfo(object):
     __slots__ = ('ref', 'old_commit', 'flags', 'note')
 
     NEW_TAG, NEW_HEAD, HEAD_UPTODATE, TAG_UPDATE, REJECTED, FORCED_UPDATE, \
-    FAST_FORWARD, ERROR = [1 << x for x in range(8)]
+        FAST_FORWARD, ERROR = [1 << x for x in range(8)]
 
     #                             %c    %-*s %-*s             -> %s       (%s)
-    re_fetch_result = re.compile("^\s*(.) (\[?[\w\s\.]+\]?)\s+(.+) -> ([/\w_\+\.-]+)(    \(.*\)?$)?")
+    re_fetch_result = re.compile("^\s*(.) (\[?[\w\s\.]+\]?)\s+(.+) -> ([/\w_\+\.\-#]+)(    \(.*\)?$)?")
 
-    _flag_map = {'!': ERROR, '+': FORCED_UPDATE, '-': TAG_UPDATE, '*': 0,
-                    '=': HEAD_UPTODATE, ' ': FAST_FORWARD}
+    _flag_map = {'!': ERROR,
+                 '+': FORCED_UPDATE,
+                 '-': TAG_UPDATE,
+                 '*': 0,
+                 '=': HEAD_UPTODATE,
+                 ' ': FAST_FORWARD}
 
     def __init__(self, ref, flags, note='', old_commit=None):
         """
@@ -259,6 +266,34 @@ class FetchInfo(object):
         except ValueError:  # unpack error
             raise ValueError("Failed to parse FETCH__HEAD line: %r" % fetch_line)
 
+        # parse flags from control_character
+        flags = 0
+        try:
+            flags |= cls._flag_map[control_character]
+        except KeyError:
+            raise ValueError("Control character %r unknown as parsed from line %r" % (control_character, line))
+        # END control char exception hanlding
+
+        # parse operation string for more info - makes no sense for symbolic refs, but we parse it anyway
+        old_commit = None
+        is_tag_operation = False
+        if 'rejected' in operation:
+            flags |= cls.REJECTED
+        if 'new tag' in operation:
+            flags |= cls.NEW_TAG
+            is_tag_operation = True
+        if 'tag update' in operation:
+            flags |= cls.TAG_UPDATE
+            is_tag_operation = True
+        if 'new branch' in operation:
+            flags |= cls.NEW_HEAD
+        if '...' in operation or '..' in operation:
+            split_token = '...'
+            if control_character == ' ':
+                split_token = split_token[:-1]
+            old_commit = repo.rev_parse(operation.split(split_token)[0])
+        # END handle refspec
+
         # handle FETCH_HEAD and figure out ref type
         # If we do not specify a target branch like master:refs/remotes/origin/master,
         # the fetch result is stored in FETCH_HEAD which destroys the rule we usually
@@ -266,15 +301,17 @@ class FetchInfo(object):
         ref_type = None
         if remote_local_ref == "FETCH_HEAD":
             ref_type = SymbolicReference
+        elif ref_type_name == "tag" or is_tag_operation:
+            # the ref_type_name can be branch, whereas we are still seeing a tag operation. It happens during
+            # testing, which is based on actual git operations
+            ref_type = TagReference
         elif ref_type_name in ("remote-tracking", "branch"):
             # note: remote-tracking is just the first part of the 'remote-tracking branch' token.
             # We don't parse it correctly, but its enough to know what to do, and its new in git 1.7something
             ref_type = RemoteReference
-        elif ref_type_name == "tag":
-            ref_type = TagReference
         else:
             raise TypeError("Cannot handle reference type: %r" % ref_type_name)
-        #END handle ref type
+        # END handle ref type
 
         # create ref instance
         if ref_type is SymbolicReference:
@@ -291,15 +328,16 @@ class FetchInfo(object):
                 # always use actual type if we get absolute paths
                 # Will always be the case if something is fetched outside of refs/remotes (if its not a tag)
                 ref_path = remote_local_ref
-                if ref_type is not TagReference and not remote_local_ref.startswith(RemoteReference._common_path_default + "/"):
+                if ref_type is not TagReference and not \
+                   remote_local_ref.startswith(RemoteReference._common_path_default + "/"):
                     ref_type = Reference
-                #END downgrade remote reference
+                # END downgrade remote reference
             elif ref_type is TagReference and 'tags/' in remote_local_ref:
                 # even though its a tag, it is located in refs/remotes
                 ref_path = join_path(RemoteReference._common_path_default, remote_local_ref)
             else:
                 ref_path = join_path(ref_type._common_path_default, remote_local_ref)
-            #END obtain refpath
+            # END obtain refpath
 
             # even though the path could be within the git conventions, we make
             # sure we respect whatever the user wanted, and disabled path checking
@@ -308,31 +346,6 @@ class FetchInfo(object):
 
         note = (note and note.strip()) or ''
 
-        # parse flags from control_character
-        flags = 0
-        try:
-            flags |= cls._flag_map[control_character]
-        except KeyError:
-            raise ValueError("Control character %r unknown as parsed from line %r" % (control_character, line))
-        # END control char exception hanlding
-
-        # parse operation string for more info - makes no sense for symbolic refs
-        old_commit = None
-        if isinstance(remote_local_ref, Reference):
-            if 'rejected' in operation:
-                flags |= cls.REJECTED
-            if 'new tag' in operation:
-                flags |= cls.NEW_TAG
-            if 'new branch' in operation:
-                flags |= cls.NEW_HEAD
-            if '...' in operation or '..' in operation:
-                split_token = '...'
-                if control_character == ' ':
-                    split_token = split_token[:-1]
-                old_commit = repo.rev_parse(operation.split(split_token)[0])
-            # END handle refspec
-        # END reference flag handling
-
         return cls(remote_local_ref, flags, note, old_commit)
 
 
@@ -490,7 +503,7 @@ class Remote(LazyMixin, Iterable):
             del(self._config_reader)        # it contains cached values, section names are different now
         except AttributeError:
             pass
-        #END handle exception
+        # END handle exception
         return self
 
     def update(self, **kwargs):
@@ -513,17 +526,19 @@ class Remote(LazyMixin, Iterable):
         # this also waits for the command to finish
         # Skip some progress lines that don't provide relevant information
         fetch_info_lines = list()
+        # Basically we want all fetch info lines which appear to be in regular form, and thus have a
+        # command character. Everything else we ignore,
+        cmds = set(PushInfo._flag_map.keys()) & set(FetchInfo._flag_map.keys())
         for line in digest_process_messages(proc.stderr, progress):
-            if line.startswith('From') or line.startswith('remote: Total') or line.startswith('POST') \
-                    or line.startswith(' ='):
-                continue
-            elif line.startswith('warning:'):
-                print >> sys.stderr, line
-                continue
-            elif line.startswith('fatal:'):
+            if line.startswith('fatal:'):
                 raise GitCommandError(("Error when fetching: %s" % line,), 2)
             # END handle special messages
-            fetch_info_lines.append(line)
+            for cmd in cmds:
+                if line[1] == cmd:
+                    fetch_info_lines.append(line)
+                    continue
+                # end find command code
+            # end for each comand code we know
         # END for each line
 
         # read head information
@@ -531,14 +546,12 @@ class Remote(LazyMixin, Iterable):
         fetch_head_info = fp.readlines()
         fp.close()
 
-        # NOTE: HACK Just disabling this line will make github repositories work much better.
-        # I simply couldn't stand it anymore, so here is the quick and dirty fix ... .
-        # This project needs a lot of work !
-        # assert len(fetch_info_lines) == len(fetch_head_info), "len(%s) != len(%s)" % (fetch_head_info, fetch_info_lines)
+        # NOTE: We assume to fetch at least enough progress lines to allow matching each fetch head line with it.
+        assert len(fetch_info_lines) >= len(fetch_head_info), "len(%s) <= len(%s)" % (fetch_head_info,
+                                                                                      fetch_info_lines)
 
         output.extend(FetchInfo._from_line(self.repo, err_line, fetch_line)
-                        for err_line, fetch_line in zip(fetch_info_lines, fetch_head_info))
-
+                      for err_line, fetch_line in zip(fetch_info_lines, fetch_head_info))
         finalize_process(proc)
         return output
 
@@ -594,6 +607,7 @@ class Remote(LazyMixin, Iterable):
             args = refspec
         else:
             args = [refspec]
+
         proc = self.repo.git.fetch(self, *args, with_extended_output=True, as_process=True, v=True, **kwargs)
         return self._get_fetch_info_from_stderr(proc, progress or RemoteProgress())
 
@@ -657,5 +671,5 @@ class Remote(LazyMixin, Iterable):
             del(self._config_reader)
         except AttributeError:
             pass
-        #END handle exception
+        # END handle exception
         return SectionConstraint(writer, self._config_section_name())
