@@ -6,37 +6,47 @@
 
 from git.exc import InvalidGitRepositoryError, NoSuchPathError
 from git.cmd import Git
+from git.refs import (
+    HEAD,
+    Head,
+    Reference,
+    TagReference,
+)
+from git.objects import (
+    Submodule,
+    RootModule,
+    Commit
+)
 from git.util import (
     Actor,
     finalize_process
-    )
-from git.refs import *
+)
 from git.index import IndexFile
-from git.objects import *
 from git.config import GitConfigParser
 from git.remote import (
-                        Remote,
-                        digest_process_messages,
-                        add_progress
-                    )
+    Remote,
+    digest_process_messages,
+    add_progress
+)
 
 from git.db import (
-                GitCmdObjectDB,
-                GitDB
-                )
+    GitCmdObjectDB,
+    GitDB
+)
 
 from gitdb.util import (
-                            join,
-                            isfile,
-                            hex_to_bin
-                        )
+    join,
+    isfile,
+    hex_to_bin
+)
 
 from fun import (
-                    rev_parse,
-                    is_git_dir,
-                    find_git_dir,
-                    touch
-                )
+    rev_parse,
+    is_git_dir,
+    find_git_dir,
+    read_gitfile,
+    touch,
+)
 
 import os
 import sys
@@ -117,6 +127,11 @@ class Repo(object):
                 self.git_dir = gitpath
                 self._working_tree_dir = curpath
                 break
+            gitpath = read_gitfile(curpath)
+            if gitpath:
+                self.git_dir = gitpath
+                self._working_tree_dir = curpath
+                break
             curpath, dummy = os.path.split(curpath)
             if not dummy:
                 break
@@ -158,9 +173,6 @@ class Repo(object):
     def __hash__(self):
         return hash(self.git_dir)
 
-    def __repr__(self):
-        return "%s(%r)" % (type(self).__name__, self.git_dir)
-
     # Description property
     def _get_description(self):
         filename = join(self.git_dir, 'description')
@@ -483,7 +495,8 @@ class Repo(object):
             # END file handling
         # END alts handling
 
-    alternates = property(_get_alternates, _set_alternates, doc="Retrieve a list of alternates paths or set a list paths to be used as alternates")
+    alternates = property(_get_alternates, _set_alternates,
+                          doc="Retrieve a list of alternates paths or set a list paths to be used as alternates")
 
     def is_dirty(self, index=True, working_tree=True, untracked_files=False):
         """
@@ -501,7 +514,7 @@ class Repo(object):
         if index:
             # diff index against HEAD
             if isfile(self.index.path) and \
-                len(self.git.diff('--cached', *default_args)):
+                    len(self.git.diff('--cached', *default_args)):
                 return True
         # END index handling
         if working_tree:
@@ -571,7 +584,8 @@ class Repo(object):
             if self.re_hexsha_only.search(firstpart):
                 # handles
                 # 634396b2f541a9f2d58b00be1a07f0c358b999b3 1 1 7        - indicates blame-data start
-                # 634396b2f541a9f2d58b00be1a07f0c358b999b3 2 2          - indicates another line of blame with the same data
+                # 634396b2f541a9f2d58b00be1a07f0c358b999b3 2 2          - indicates
+                # another line of blame with the same data
                 digits = parts[-1].split(" ")
                 if len(digits) == 3:
                     info = {'id': firstpart}
@@ -615,11 +629,12 @@ class Repo(object):
                             c = commits.get(sha)
                             if c is None:
                                 c = Commit(self, hex_to_bin(sha),
-                                             author=Actor._from_string(info['author'] + ' ' + info['author_email']),
-                                             authored_date=info['author_date'],
-                                             committer=Actor._from_string(info['committer'] + ' ' + info['committer_email']),
-                                             committed_date=info['committer_date'],
-                                             message=info['summary'])
+                                           author=Actor._from_string(info['author'] + ' ' + info['author_email']),
+                                           authored_date=info['author_date'],
+                                           committer=Actor._from_string(
+                                               info['committer'] + ' ' + info['committer_email']),
+                                           committed_date=info['committer_date'],
+                                           message=info['summary'])
                                 commits[sha] = c
                             # END if commit objects needs initial creation
                             m = self.re_tab_full_line.search(line)
@@ -653,11 +668,11 @@ class Repo(object):
         :return: ``git.Repo`` (the newly created repo)"""
 
         if mkdir and path and not os.path.exists(path):
-            os.makedirs(path, 0755)
+            os.makedirs(path, 0o755)
 
         # git command automatically chdir into the directory
         git = Git(path)
-        output = git.init(**kwargs)
+        git.init(**kwargs)
         return Repo(path)
 
     @classmethod
@@ -688,10 +703,11 @@ class Repo(object):
         # END windows handling
 
         try:
-            proc = git.clone(url, path, with_extended_output=True, as_process=True, v=True, **add_progress(kwargs, git, progress))
+            proc = git.clone(url, path, with_extended_output=True, as_process=True,
+                             v=True, **add_progress(kwargs, git, progress))
             if progress:
                 digest_process_messages(proc.stderr, progress)
-            #END handle progress
+            # END handle progress
             finalize_process(proc)
         finally:
             if prev_cwd is not None:
