@@ -3,11 +3,12 @@
 #
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
-
+from __future__ import print_function
 import os
 import sys
-from git import Repo, Remote, GitCommandError
+from git import Repo, Remote, GitCommandError, Git
 from unittest import TestCase
+import time
 import tempfile
 import shutil
 import cStringIO
@@ -15,9 +16,9 @@ import cStringIO
 GIT_REPO = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(__file__))))
 
 __all__ = (
-            'fixture_path', 'fixture', 'absolute_project_path', 'StringProcessAdapter',
-            'with_rw_repo', 'with_rw_and_rw_remote_repo', 'TestBase', 'TestCase', 'GIT_REPO'
-            )
+    'fixture_path', 'fixture', 'absolute_project_path', 'StringProcessAdapter',
+    'with_rw_repo', 'with_rw_and_rw_remote_repo', 'TestBase', 'TestCase', 'GIT_REPO'
+)
 
 #{ Routines
 
@@ -74,7 +75,7 @@ def _rmtree_onerror(osremove, fullpath, exec_info):
     if os.name != 'nt' or osremove is not os.remove:
         raise
 
-    os.chmod(fullpath, 0777)
+    os.chmod(fullpath, 0o777)
     os.remove(fullpath)
 
 
@@ -95,7 +96,7 @@ def with_rw_repo(working_tree_ref, bare=False):
             prefix = 'non_'
             if bare:
                 prefix = ''
-            #END handle prefix
+            # END handle prefix
             repo_dir = _mktemp("%sbare_%s" % (prefix, func.__name__))
             rw_repo = self.rorepo.clone(repo_dir, shared=True, bare=bare, n=True)
 
@@ -110,7 +111,7 @@ def with_rw_repo(working_tree_ref, bare=False):
                 try:
                     return func(self, rw_repo)
                 except:
-                    print >> sys.stderr, "Keeping repo after failure: %s" % repo_dir
+                    print("Keeping repo after failure: %s" % repo_dir, file=sys.stderr)
                     repo_dir = None
                     raise
             finally:
@@ -149,6 +150,7 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
     This setup allows you to test push and pull scenarios and hooks nicely.
 
     See working dir info in with_rw_repo
+    :note: We attempt to launch our own invocation of git-daemon, which will be shutdown at the end of the test.
     """
     assert isinstance(working_tree_ref, basestring), "Decorator requires ref name for working tree checkout"
 
@@ -158,7 +160,8 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
             repo_dir = _mktemp("remote_clone_non_bare_repo")
 
             rw_remote_repo = self.rorepo.clone(remote_repo_dir, shared=True, bare=True)
-            rw_repo = rw_remote_repo.clone(repo_dir, shared=True, bare=False, n=True)       # recursive alternates info ?
+            # recursive alternates info ?
+            rw_repo = rw_remote_repo.clone(repo_dir, shared=True, bare=False, n=True)
             rw_repo.head.commit = working_tree_ref
             rw_repo.head.reference.checkout()
 
@@ -185,17 +188,35 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
 
             d_remote.config_writer.set('url', remote_repo_url)
 
+            temp_dir = os.path.dirname(_mktemp())
+            # On windows, this will fail ... we deal with failures anyway and default to telling the user to do it
+            try:
+                gd = Git().daemon(temp_dir, as_process=True)
+                # yes, I know ... fortunately, this is always going to work if sleep time is just large enough
+                time.sleep(0.5)
+            except Exception:
+                gd = None
+            # end
+
             # try to list remotes to diagnoes whether the server is up
             try:
                 rw_repo.git.ls_remote(d_remote)
-            except GitCommandError, e:
-                print str(e)
+            except GitCommandError as e:
+                # We assume in good faith that we didn't start the daemon - but make sure we kill it anyway
+                # Of course we expect it to work here already, but maybe there are timing constraints
+                # on some platforms ?
+                if gd is not None:
+                    os.kill(gd.proc.pid, 15)
+                print(str(e))
                 if os.name == 'nt':
-                    raise AssertionError('git-daemon needs to run this test, but windows does not have one. Otherwise, run: git-daemon "%s"' % os.path.dirname(_mktemp()))
+                    msg = "git-daemon needs to run this test, but windows does not have one. "
+                    msg += 'Otherwise, run: git-daemon "%s"' % temp_dir
+                    raise AssertionError(msg)
                 else:
-                    raise AssertionError('Please start a git-daemon to run this test, execute: git-daemon "%s"' % os.path.dirname(_mktemp()))
+                    msg = 'Please start a git-daemon to run this test, execute: git-daemon "%s"' % temp_dir
+                    raise AssertionError(msg)
                 # END make assertion
-            #END catch ls remote error
+            # END catch ls remote error
 
             # adjust working dir
             prev_cwd = os.getcwd()
@@ -203,11 +224,16 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
             try:
                 return func(self, rw_repo, rw_remote_repo)
             finally:
+                # gd.proc.kill() ... no idea why that doesn't work
+                os.kill(gd.proc.pid, 15)
+
                 os.chdir(prev_cwd)
                 rw_repo.git.clear_cache()
                 rw_remote_repo.git.clear_cache()
                 shutil.rmtree(repo_dir, onerror=_rmtree_onerror)
                 shutil.rmtree(remote_repo_dir, onerror=_rmtree_onerror)
+
+                gd.proc.wait()
             # END cleanup
         # END bare repo creator
         remote_repo_creator.__name__ = func.__name__
