@@ -3,9 +3,9 @@
 #
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
-
-from lib import *
-from git import *
+from __future__ import print_function
+from .lib import TestBigRepoRW
+from git import Commit
 from gitdb import IStream
 from git.test.test_commit import assert_commit_serialization
 from cStringIO import StringIO
@@ -46,47 +46,49 @@ class TestPerformance(TestBigRepoRW):
             # END for each object
         # END for each commit
         elapsed_time = time() - st
-        print >> sys.stderr, "Traversed %i Trees and a total of %i unchached objects in %s [s] ( %f objs/s )" % (nc, no, elapsed_time, no / elapsed_time)
+        print("Traversed %i Trees and a total of %i unchached objects in %s [s] ( %f objs/s )"
+              % (nc, no, elapsed_time, no / elapsed_time), file=sys.stderr)
 
     def test_commit_traversal(self):
         # bound to cat-file parsing performance
         nc = 0
         st = time()
-        for c in self.gitrorepo.commit(self.head_sha_2k).traverse(branch_first=False):
+        for c in self.gitrorepo.commit().traverse(branch_first=False):
             nc += 1
             self._query_commit_info(c)
         # END for each traversed commit
         elapsed_time = time() - st
-        print >> sys.stderr, "Traversed %i Commits in %s [s] ( %f commits/s )" % (nc, elapsed_time, nc / elapsed_time)
+        print("Traversed %i Commits in %s [s] ( %f commits/s )"
+              % (nc, elapsed_time, nc / elapsed_time), file=sys.stderr)
 
     def test_commit_iteration(self):
         # bound to stream parsing performance
         nc = 0
         st = time()
-        for c in Commit.iter_items(self.gitrorepo, self.head_sha_2k):
+        for c in Commit.iter_items(self.gitrorepo, self.gitrorepo.head):
             nc += 1
             self._query_commit_info(c)
         # END for each traversed commit
         elapsed_time = time() - st
-        print >> sys.stderr, "Iterated %i Commits in %s [s] ( %f commits/s )" % (nc, elapsed_time, nc / elapsed_time)
+        print("Iterated %i Commits in %s [s] ( %f commits/s )"
+              % (nc, elapsed_time, nc / elapsed_time), file=sys.stderr)
 
     def test_commit_serialization(self):
-        assert_commit_serialization(self.gitrwrepo, self.head_sha_2k, True)
+        assert_commit_serialization(self.gitrwrepo, self.gitrwrepo.head, True)
 
         rwrepo = self.gitrwrepo
         make_object = rwrepo.odb.store
         # direct serialization - deserialization can be tested afterwards
         # serialization is probably limited on IO
-        hc = rwrepo.commit(self.head_sha_2k)
+        hc = rwrepo.commit(rwrepo.head)
 
-        commits = list()
         nc = 5000
         st = time()
         for i in xrange(nc):
             cm = Commit(rwrepo, Commit.NULL_BIN_SHA, hc.tree,
-                            hc.author, hc.authored_date, hc.author_tz_offset,
-                            hc.committer, hc.committed_date, hc.committer_tz_offset,
-                            str(i), parents=hc.parents, encoding=hc.encoding)
+                        hc.author, hc.authored_date, hc.author_tz_offset,
+                        hc.committer, hc.committed_date, hc.committer_tz_offset,
+                        str(i), parents=hc.parents, encoding=hc.encoding)
 
             stream = StringIO()
             cm._serialize(stream)
@@ -97,4 +99,5 @@ class TestPerformance(TestBigRepoRW):
         # END commit creation
         elapsed = time() - st
 
-        print >> sys.stderr, "Serialized %i commits to loose objects in %f s ( %f commits / s )" % (nc, elapsed, nc / elapsed)
+        print("Serialized %i commits to loose objects in %f s ( %f commits / s )"
+              % (nc, elapsed, nc / elapsed), file=sys.stderr)
