@@ -5,23 +5,30 @@
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
 import git.objects.base as base
-import git.refs as refs
 import os
 
-from git.test.lib import *
-from git import *
-from itertools import chain
+from git.test.lib import (
+    TestBase,
+    assert_raises,
+    with_rw_repo,
+    with_rw_and_rw_remote_repo
+)
+from git import (
+    Blob,
+    Tree,
+    Commit,
+    TagObject
+)
 from git.objects.util import get_object_type_by_name
 from gitdb.util import hex_to_bin
-import tempfile
 
 
 class TestBase(TestBase):
 
     type_tuples = (("blob", "8741fc1d09d61f02ffd8cded15ff603eff1ec070", "blob.py"),
-                     ("tree", "3a6a5e3eeed3723c09f1ef0399f81ed6b8d82e79", "directory"),
-                     ("commit", "4251bd59fb8e11e40c40548cba38180a9536118c", None),
-                     ("tag", "e56a60e8e9cd333cfba0140a77cd12b0d9398f10", None))
+                   ("tree", "3a6a5e3eeed3723c09f1ef0399f81ed6b8d82e79", "directory"),
+                   ("commit", "4251bd59fb8e11e40c40548cba38180a9536118c", None),
+                   ("tag", "e56a60e8e9cd333cfba0140a77cd12b0d9398f10", None))
 
     def test_base_object(self):
         # test interface of base object classes
