@@ -7,14 +7,14 @@
 import os
 import mock
 from git.test.lib import (TestBase,
-                            patch,
-                            raises,
-                            assert_equal,
-                            assert_true,
-                            assert_match,
-                            fixture_path)
+                          patch,
+                          raises,
+                          assert_equal,
+                          assert_true,
+                          assert_match,
+                          fixture_path)
 from git import (Git,
-                    GitCommandError)
+                 GitCommandError)
 
 
 class TestGit(TestBase):
@@ -50,7 +50,9 @@ class TestGit(TestBase):
         assert_equal(["--max-count"], self.git.transform_kwargs(**{'max_count': True}))
         assert_equal(["--max-count=5"], self.git.transform_kwargs(**{'max_count': 5}))
 
-        assert_equal(["-s", "-t"], self.git.transform_kwargs(**{'s': True, 't': True}))
+        # order is undefined
+        res = self.git.transform_kwargs(**{'s': True, 't': True})
+        assert ['-s', '-t'] == res or ['-t', '-s'] == res
 
     def test_it_executes_git_to_shell_and_returns_result(self):
         assert_match('^git version [\d\.]{2}.*$', self.git.execute(["git", "version"]))
@@ -104,17 +106,18 @@ class TestGit(TestBase):
         assert isinstance(v, tuple)
         for n in v:
             assert isinstance(n, int)
-        #END verify number types
+        # END verify number types
 
     def test_cmd_override(self):
         prev_cmd = self.git.GIT_PYTHON_GIT_EXECUTABLE
         try:
             # set it to something that doens't exist, assure it raises
-            type(self.git).GIT_PYTHON_GIT_EXECUTABLE = os.path.join("some", "path", "which", "doesn't", "exist", "gitbinary")
+            type(self.git).GIT_PYTHON_GIT_EXECUTABLE = os.path.join(
+                "some", "path", "which", "doesn't", "exist", "gitbinary")
             self.failUnlessRaises(OSError, self.git.version)
         finally:
             type(self.git).GIT_PYTHON_GIT_EXECUTABLE = prev_cmd
-        #END undo adjustment
+        # END undo adjustment
 
     def test_options_are_passed_to_git(self):
         # This work because any command after git --version is ignored
@@ -124,7 +127,7 @@ class TestGit(TestBase):
 
     def test_single_char_git_options_are_passed_to_git(self):
         input_value = 'TestValue'
-        output_value = self.git(c='user.name={}'.format(input_value)).config('--get', 'user.name')
+        output_value = self.git(c='user.name=%s' % input_value).config('--get', 'user.name')
         self.assertEquals(input_value, output_value)
 
     def test_change_to_transform_kwargs_does_not_break_command_options(self):
