@@ -1,6 +1,12 @@
-from git.test.lib import *
+from git.test.lib import (
+    TestBase,
+    fixture_path
+)
 from git.objects import IndexObject
-from git.refs import *
+from git.refs import (
+    RefLogEntry,
+    RefLog
+)
 from git.util import Actor
 
 import tempfile
@@ -53,7 +59,7 @@ class TestRefLog(TestBase):
         pp = 'reflog_invalid_'
         for suffix in ('oldsha', 'newsha', 'email', 'date', 'sep'):
             self.failUnlessRaises(ValueError, RefLog.from_file, fixture_path(pp + suffix))
-        #END for each invalid file
+        # END for each invalid file
 
         # cannot write an uninitialized reflog
         self.failUnlessRaises(ValueError, RefLog().write)
@@ -93,7 +99,7 @@ class TestRefLog(TestBase):
             # ... and negative
             for idx in (-1, -24):
                 RefLog.entry_at(rlp, idx)
-            #END for each index to read
+            # END for each index to read
         # END for each reflog
 
         # finally remove our temporary data
