@@ -4,9 +4,20 @@
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
-from mock import *
-from git.test.lib import *
-from git import *
+from git.test.lib import (
+    TestBase,
+    with_rw_repo
+)
+from git import (
+    Reference,
+    Head,
+    TagReference,
+    RemoteReference,
+    Commit,
+    SymbolicReference,
+    GitCommandError,
+    RefLog
+)
 import git.refs as refs
 from git.util import Actor
 from git.objects.tag import TagObject
@@ -155,10 +166,10 @@ class TestRefs(TestBase):
         assert len(types_found) >= 3
 
     def test_is_valid(self):
-        assert Reference(self.rorepo, 'refs/doesnt/exist').is_valid() == False
+        assert not Reference(self.rorepo, 'refs/doesnt/exist').is_valid()
         assert self.rorepo.head.is_valid()
         assert self.rorepo.head.reference.is_valid()
-        assert SymbolicReference(self.rorepo, 'hellothere').is_valid() == False
+        assert not SymbolicReference(self.rorepo, 'hellothere').is_valid()
 
     def test_orig_head(self):
         assert type(self.rorepo.head.orig_head()) == SymbolicReference
@@ -297,7 +308,7 @@ class TestRefs(TestBase):
             if remote_head_name in refs:
                 RemoteReference.delete(rw_repo, refs[remote_head_name])
                 del(refs[remote_head_name])
-            #END handle HEAD deletion
+            # END handle HEAD deletion
 
             RemoteReference.delete(rw_repo, *refs)
             remote_refs_so_far += len(refs)
