@@ -3,21 +3,36 @@
 #
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
-from git.test.lib import (patch,
-                          TestBase,
-                          with_rw_repo,
-                          fixture,
-                          GIT_REPO,
-                          assert_false,
-                          assert_equal,
-                          assert_true,
-                          raises)
-from git import *
+from git.test.lib import (
+    patch,
+    TestBase,
+    with_rw_repo,
+    fixture,
+    assert_false,
+    assert_equal,
+    assert_true,
+    raises
+)
+from git import (
+    InvalidGitRepositoryError,
+    Repo,
+    NoSuchPathError,
+    Head,
+    Commit,
+    Tree,
+    IndexFile,
+    Git,
+    Reference,
+    GitDB,
+    Submodule,
+    GitCmdObjectDB
+)
 from git.util import join_path_native
 from git.exc import BadObject
-from gitdb.util import hex_to_bin, bin_to_hex
+from gitdb.util import bin_to_hex
 
-import os, sys
+import os
+import sys
 import tempfile
 import shutil
 from cStringIO import StringIO
@@ -33,12 +48,13 @@ class TestRepo(TestBase):
     def test_new_should_raise_on_non_existant_path(self):
         Repo("repos/foobar")
 
-    def test_repo_creation_from_different_paths(self):
-        r_from_gitdir = Repo(self.rorepo.git_dir)
-        assert r_from_gitdir.git_dir == self.rorepo.git_dir
+    @with_rw_repo('0.3.2.1')
+    def test_repo_creation_from_different_paths(self, rw_repo):
+        r_from_gitdir = Repo(rw_repo.git_dir)
+        assert r_from_gitdir.git_dir == rw_repo.git_dir
         assert r_from_gitdir.git_dir.endswith('.git')
-        assert not self.rorepo.git.working_dir.endswith('.git')
-        assert r_from_gitdir.git.working_dir == self.rorepo.git.working_dir
+        assert not rw_repo.git.working_dir.endswith('.git')
+        assert r_from_gitdir.git.working_dir == rw_repo.git.working_dir
 
     def test_description(self):
         txt = "Test repository"
@@ -141,7 +157,7 @@ class TestRepo(TestBase):
             for path in (git_dir_rela, git_dir_abs):
                 r = Repo.init(path=path, bare=True)
                 assert isinstance(r, Repo)
-                assert r.bare == True
+                assert r.bare is True
                 assert os.path.isdir(r.git_dir)
 
                 self._assert_empty_repo(r)
@@ -177,7 +193,7 @@ class TestRepo(TestBase):
             os.makedirs(git_dir_rela)
             os.chdir(git_dir_rela)
             r = Repo.init(bare=False)
-            r.bare == False
+            assert r.bare is False
 
             self._assert_empty_repo(r)
         finally:
@@ -209,8 +225,7 @@ class TestRepo(TestBase):
         self.rorepo.alternates = cur_alternates
 
     def test_repr(self):
-        path = os.path.join(os.path.abspath(GIT_REPO), '.git')
-        assert_equal('<git.Repo "%s">' % path, repr(self.rorepo))
+        assert repr(self.rorepo).startswith('<git.Repo ')
 
     def test_is_dirty_with_bare_repository(self):
         orig_value = self.rorepo._bare
@@ -229,7 +244,7 @@ class TestRepo(TestBase):
         # END index
         orig_val = self.rorepo._bare
         self.rorepo._bare = True
-        assert self.rorepo.is_dirty() == False
+        assert self.rorepo.is_dirty() is False
         self.rorepo._bare = orig_val
 
     def test_head(self):
@@ -277,16 +292,16 @@ class TestRepo(TestBase):
     def test_blame_real(self):
         c = 0
         for item in self.rorepo.head.commit.tree.traverse(
-                    predicate=lambda i, d: i.type == 'blob' and i.path.endswith('.py')):
+                predicate=lambda i, d: i.type == 'blob' and i.path.endswith('.py')):
             c += 1
-            b = self.rorepo.blame(self.rorepo.head, item.path)
-        #END for each item to traverse
+            self.rorepo.blame(self.rorepo.head, item.path)
+        # END for each item to traverse
         assert c
 
     def test_untracked_files(self):
         base = self.rorepo.working_tree_dir
         files = (join_path_native(base, "__test_myfile"),
-                    join_path_native(base, "__test_other_file"))
+                 join_path_native(base, "__test_other_file"))
         num_recently_untracked = 0
         try:
             for fpath in files:
@@ -502,7 +517,7 @@ class TestRepo(TestBase):
                     assert obj.type == ref.object.type
                     num_resolved += 1
                 except BadObject:
-                    print "failed on %s" % path_section
+                    print ("failed on %s" % path_section)
                     # is fine, in case we have something like 112, which belongs to remotes/rname/merge-requests/112
                     pass
                 # END exception handling
@@ -578,10 +593,7 @@ class TestRepo(TestBase):
             # all additional specs work as well
             assert rev_parse(refspec + "^{tree}") == head.commit.tree
             assert rev_parse(refspec + ":CHANGES").type == 'blob'
-        #END operate on non-detached head
-
-        # the last position
-        assert rev_parse('@{1}') != head.commit
+        # END operate on non-detached head
 
         # position doesn't exist
         self.failUnlessRaises(IndexError, rev_parse, '@{10000}')
@@ -589,6 +601,9 @@ class TestRepo(TestBase):
         # currently, nothing more is supported
         self.failUnlessRaises(NotImplementedError, rev_parse, "@{1 week ago}")
 
+        # the last position
+        assert rev_parse('@{1}') != head.commit
+
     def test_repo_odbtype(self):
         target_type = GitDB
         if sys.version_info[1] < 5:
@@ -615,3 +630,20 @@ class TestRepo(TestBase):
         assert isinstance(sm, Submodule)
 
         # note: the rest of this functionality is tested in test_submodule
+
+    @with_rw_repo('HEAD')
+    def test_git_file(self, rwrepo):
+        # Move the .git directory to another location and create the .git file.
+        real_path_abs = os.path.abspath(join_path_native(rwrepo.working_tree_dir, '.real'))
+        os.rename(rwrepo.git_dir, real_path_abs)
+        git_file_path = join_path_native(rwrepo.working_tree_dir, '.git')
+        open(git_file_path, 'wb').write(fixture('git_file'))
+
+        # Create a repo and make sure it's pointing to the relocated .git directory.
+        git_file_repo = Repo(rwrepo.working_tree_dir)
+        assert os.path.abspath(git_file_repo.git_dir) == real_path_abs
+
+        # Test using an absolute gitdir path in the .git file.
+        open(git_file_path, 'wb').write('gitdir: %s\n' % real_path_abs)
+        git_file_repo = Repo(rwrepo.working_tree_dir)
+        assert os.path.abspath(git_file_repo.git_dir) == real_path_abs
