@@ -5,12 +5,12 @@
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
 import os
-from git.test.lib import *
-from git import *
-from git.objects.fun import (
-                                traverse_tree_recursive,
-                                traverse_trees_recursive
-                            )
+from git.test.lib import TestBase
+from git import (
+    Tree,
+    Blob
+)
+
 from cStringIO import StringIO
 
 
