@@ -4,13 +4,25 @@
 # This module is part of GitPython and is released under
 # the BSD License: http://www.opensource.org/licenses/bsd-license.php
 
-import os
 import tempfile
 
-from git.util import *
-from git.test.lib import *
-from git.objects.util import *
-from git import *
+from git.test.lib import (
+    TestBase,
+    assert_equal
+)
+from git.util import (
+    LockFile,
+    BlockingLockFile,
+    get_user_id,
+    Actor,
+    IterableList
+)
+from git.objects.util import (
+    altz_to_utctz_str,
+    utctz_to_altz,
+    verify_utctz,
+    parse_date,
+)
 from git.cmd import dashify
 
 import time
@@ -102,9 +114,9 @@ class TestUtils(TestBase):
         iso3 = ("2005.04.07 22:13:11 -0000", 0)
         alt = ("04/07/2005 22:13:11", 0)
         alt2 = ("07.04.2005 22:13:11", 0)
-        veri_time = 1112904791      # the time this represents
+        veri_time_utc = 1112911991      # the time this represents, in time since epoch, UTC
         for date, offset in (rfc, iso, iso2, iso3, alt, alt2):
-            assert_rval(parse_date(date), veri_time, offset)
+            assert_rval(parse_date(date), veri_time_utc, offset)
         # END for each date type
 
         # and failure
@@ -116,7 +128,7 @@ class TestUtils(TestBase):
         for cr in (None, self.rorepo.config_reader()):
             assert isinstance(Actor.committer(cr), Actor)
             assert isinstance(Actor.author(cr), Actor)
-        #END assure config reader is handled
+        # END assure config reader is handled
 
     def test_iterable_list(self):
         for args in (('name',), ('name', 'prefix_')):
@@ -163,4 +175,4 @@ class TestUtils(TestBase):
 
             self.failUnlessRaises(IndexError, l.__delitem__, 0)
             self.failUnlessRaises(IndexError, l.__delitem__, 'something')
-        #END for each possible mode
+        # END for each possible mode
